//========================================================================
// This program is distributed under the GPL license.
// Copyright 2004 Juha Nieminen
//========================================================================

#ifndef BWBITMAP_INC
#define BWBITMAP_INC

#include <string>

class BWBitmap
{
 public:
    BWBitmap(unsigned width=0, unsigned height=0, unsigned char bgColor=255);
    ~BWBitmap();

    // Configuring methods:
    void setLineWidth(double width);
    void setDrawingColor(unsigned char color) { drawingColor_ = color; }
    void setFont(const BWBitmap& fontBitmap,
                 unsigned charWidth, unsigned charHeight);

    // Drawing methods:
    void line(double x1, double y1, double x2, double y2);
    void circle(double x, double y, double radius);
    void filledCircle(double x, double y, double radius);
    void character(unsigned charIndex, unsigned x, unsigned y);

    // PNG reading and writing:
    bool readPNG(const std::string& filename);
    bool writePNG(const std::string& filename);




//========================================================================
 private:
    unsigned char* bitmap_;
    unsigned width_, height_;
    double lineWidth_;
    unsigned char drawingColor_;
    const BWBitmap* font_;
    unsigned charWidth_, charHeight_;

    // Raw pixel set and get:
    inline void put(unsigned x, unsigned y, unsigned char color);
    inline unsigned char get(unsigned x, unsigned y) const;

    BWBitmap(const BWBitmap&);
    BWBitmap& operator=(const BWBitmap&);
};

#endif
